#!/usr/bin/env bash

# ---------------------------------------------
# Licensed Materials - Property of IBM
# (C) Copyright IBM Corporation 2021
# ---------------------------------------------

#run scripts at relative path
scriptdir="$(dirname "$0")"
cd "$scriptdir"

source ./.security_config

###create the podman/docker alias
if [[ $TA_LOCAL_TEMP_PODMAN_INSTALL = true ]]; then
  shopt -s expand_aliases
  source ./.podman_config
fi


source ./checkPodsRunning.sh
source ./installHelper.sh
source ./imageHelper.sh

mkdir -p ../logs

source ./installHelper.sh
source ./findHost.sh
replaceHost

sleep 1

ui=$(docker ps -a | grep transformation-advisor-ui | awk '{print $1}')
couch=$(docker ps -a | grep transformation-advisor-db | awk '{print $1}')
server=$(docker ps -a | grep transformation-advisor-server | awk '{print $1}')
neo4j=$(docker ps -a | grep transformation-advisor-neo4j | awk '{print $1}')

if [[ ! -z $ui && ! -z $couch && ! -z $server && ! -z $neo4j ]]

then

startTA

else

if [ ! -d "../data" ]; then
mkdir ../data
chmod ugo+rwx ../data
fi

if [ ! -d "../graph_data" ]; then
mkdir ../graph_data
chmod ugo+rwx ../graph_data
fi

startDockerCompose

fi

# set the protocol, reset the protocol, as startDockerCompose set to something else
PROTOCOL=http
# translate into lower case
TA_AUTH_ENABLE_TLS_lower_case=$(echo "$TA_AUTH_ENABLE_TLS" | tr '[:upper:]' '[:lower:]')

if [[ $TA_AUTH_ENABLE_TLS_lower_case == 'true' ]]; then
	PROTOCOL=https
fi


# this will print dots like ... in a background job
source ./helper.sh
showConfiguringTA

########### testing for ui, couchDB and liberty containers are running #######
checkUIPodMain
checkDBPod
checkLibertyOnline
##############################################################################

# this will kill the dots generation background job
killBackgroundJob

displayTARunningStatus
